==> org-lsst-ccs-subsystem-fcs-gui-4.0.2-sources.jar: org/lsst/ccs/subsystems/fcs/testbench/ui/TestbenchLPCBottomPanel.java <==
/*
 * To change this license header, choose License Headers in Project Properties.
 * To change this template file, choose Tools | Templates
 * and open the template in the editor.
 */
package org.lsst.ccs.subsystems.fcs.testbench.ui;

import javax.swing.tree.DefaultMutableTreeNode;
import static org.lsst.ccs.subsystems.fcs.FCSCst.CHANGER_TCPPROXY_NAME;
import org.lsst.ccs.subsystems.fcs.ui.commons.BottomPanel;

/**
 *
 * @author virieux
 */
public class TestbenchLPCBottomPanel extends BottomPanel {
    private static final long serialVersionUID = 1029091381957999618L;

    public TestbenchLPCBottomPanel(TestbenchLPCGatherPanel gatherPanel, String title) {
        super(gatherPanel, title);
    }
    
    @Override
    public void createNodes(DefaultMutableTreeNode top) {

        if (gatherPanel == null) {
            gatherPanel = new TestbenchLPCGatherPanel(CHANGER_TCPPROXY_NAME);
        }
        DefaultMutableTreeNode devicesNode = new DefaultMutableTreeNode("CANopen devices");
        devicesNode.add(new DefaultMutableTreeNode(gatherPanel.getHardwarePanel()));
        devicesNode.add(new DefaultMutableTreeNode(((TestbenchLPCGatherPanel)gatherPanel).getAxisXControllerPanel()));
        devicesNode.add(new DefaultMutableTreeNode(((TestbenchLPCGatherPanel)gatherPanel).getAxisZControllerPanel()));
        top.add(devicesNode);

        top.add(new DefaultMutableTreeNode(((TestbenchLPCGatherPanel)gatherPanel).getLpcAxisXPanel()));

        top.add(new DefaultMutableTreeNode(((TestbenchLPCGatherPanel)gatherPanel).getLpcAxisZPanel()));

    }
    
}

==> org-lsst-ccs-subsystem-fcs-gui-5.0.3-sources.jar: org/lsst/ccs/subsystems/fcs/testbench/ui/TestbenchLPCBottomPanel.java <==
/*
 * To change this license header, choose License Headers in Project Properties.
 * To change this template file, choose Tools | Templates
 * and open the template in the editor.
 */
package org.lsst.ccs.subsystems.fcs.testbench.ui;

import javax.swing.tree.DefaultMutableTreeNode;
import static org.lsst.ccs.subsystems.fcs.FCSCst.CHANGER_TCPPROXY_NAME;
import org.lsst.ccs.subsystems.fcs.ui.commons.BottomPanel;

/**
 *
 * @author virieux
 */
public class TestbenchLPCBottomPanel extends BottomPanel {
    private static final long serialVersionUID = 1029091381957999618L;

    public TestbenchLPCBottomPanel(TestbenchLPCGatherPanel gatherPanel, String title) {
        super(gatherPanel, title);
    }
    
    @Override
    public void createNodes(DefaultMutableTreeNode top) {

        if (gatherPanel == null) {
            gatherPanel = new TestbenchLPCGatherPanel(CHANGER_TCPPROXY_NAME);
        }
        DefaultMutableTreeNode devicesNode = new DefaultMutableTreeNode("CANopen devices");
        devicesNode.add(new DefaultMutableTreeNode(gatherPanel.getCanOpenHardwareListPanel()));
        devicesNode.add(new DefaultMutableTreeNode(((TestbenchLPCGatherPanel)gatherPanel).getAxisXControllerPanel()));
        devicesNode.add(new DefaultMutableTreeNode(((TestbenchLPCGatherPanel)gatherPanel).getAxisZControllerPanel()));
        top.add(devicesNode);

        top.add(new DefaultMutableTreeNode(((TestbenchLPCGatherPanel)gatherPanel).getLpcAxisXPanel()));

        top.add(new DefaultMutableTreeNode(((TestbenchLPCGatherPanel)gatherPanel).getLpcAxisZPanel()));

    }
    
}
